@@ -2,6 +2,7 @@ package App::Tel::HostRange;
 
 use strict;
 use warnings;
+use Module::Load;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -9,9 +10,11 @@ our @EXPORT = qw();
 our @EXPORT_OK = qw ( check_hostrange );
 our $_have_netaddr;  # can't set a default because this happens after the BEGIN block
 
+# needed because CPAN won't index undef since it's a lower version number
+our $VERSION = '0.201503';
+
 BEGIN {
-    if (eval { require NetAddr::IP; }) {
-        NetAddr::IP->import();
+    if (eval { Module::Load::load NetAddr::IP; 1; }) {
         $_have_netaddr=1;
     } else {
         $_have_netaddr=0;
@@ -22,15 +25,6 @@ BEGIN {
 
 App::Tel::HostRange - Support for HostRanges
 
-=head1 VERSION
-
-0.2015_02
-
-=cut
-
-our $VERSION = eval  { 0.2015_02 };
-
-
 =head1 SYNOPSIS
 
     if (check_hostrange($_, $host));
